==> tinyca-0.4.6.tar.gz: TinyCA/lib/TCONFIG.pm <==
# Copyright (c) Stephan Martin <sm@sm-zone.net>
#
# $Id: TCONFIG.pm,v 1.4 2003/06/19 21:46:43 sm Exp $
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.

use strict;

package TCONFIG;

sub new {
   my $self  = {};
   my $that  = shift;
   my $class = ref($that) || $that;

   bless($self, $class);
}

sub init_config {
   my $self = shift;
   my $main = shift;
   my $ca   = shift;

   my($file, @lines, $i, $section, $l, $k, $v);

   if(not defined($ca)) {
     $ca = $main->{'CA'}->{'actca'};
   }
   if(not defined($ca)) {
      $main->print_warning("No CA given");
      return;
   }

   $file = $main->{'CA'}->{$ca}->{'cnf'};

   open(IN, "<$file") || do {
      $main->print_warning("Can't open Configuration");
      return;
   };

   @lines = <IN>;
   close IN;
   chomp(@lines);

   # clean old configuration
   foreach $k (keys(%$self)) {
      delete($self->{$k});
   }

   foreach $l (@lines) {
      next if $l =~ /^#/;
      next if $l =~ /^$/;
      next if $l =~ /^ *$/;

      # find section
      if($l =~ /\[\s*([^\s]+)\s*\]/) {
         $section = $1;
      } elsif ($l =~ /^([^\s\t]+)[\s\t]*=[\s\t]*([^\s\t]+.*)$/) {
         if($section eq "ca" ||
            $section eq "policy_client" ||
            $section eq "policy_server" ||
            $section eq "req" ||
            $section eq "req_distinguished_name" ||
            $section eq "v3_req" ||
            $section eq "req_attributes") {
            if(not defined($self->{$section})) {
               $self->{$section} = [];
            }
            push(@{$self->{$section}}, $l);
         } else {
            $k = $1;
            $v = $2;
            if(not defined($self->{$section})) {
               $self->{$section} = {};
            }
            $self->{$section}->{$k} = $v;
         }
      }
   }
   return;
}

sub config_ca {
   my $self = shift;
   my $main = shift;
   my $ca   = shift;

   my($action);

   if(not defined($ca)) { 
      $ca = $main->{'CA'}->{'actca'};
   }
   if(not defined($ca)) {
      $main->print_warning("Can't get CA name");
   }

   $action = $main->show_config_ca($ca);

   return if $action eq 'Cancel';

   _write_config($self, $main, $ca);

   return;
}

sub config_server {
   my $self = shift;
   my $main = shift;
   my $ca   = shift;

   my($action);

   if(not defined($ca)) { 
      $ca = $main->{'CA'}->{'actca'};
   }
   if(not defined($ca)) {
      $main->print_warning("Can't get CA name");
   }

   $action = $main->show_config_server($ca);

   return if $action eq 'Cancel';

   _write_config($self, $main, $ca);

   return;
}

sub config_client {
   my $self = shift;
   my $main = shift;
   my $ca   = shift;

   my($action);

   if(not defined($ca)) { 
      $ca = $main->{'CA'}->{'actca'};
   }
   if(not defined($ca)) {
      $main->print_warning("Can't get CA name");
   }

   $action = $main->show_config_client($ca);

   return if $action eq 'Cancel';

   _write_config($self, $main, $ca);

   return;
}

sub config_crl {
   my $self = shift;
   my $main = shift;
   my $ca   = shift;

   my($action);

   if(not defined($ca)) { 
      $ca = $main->{'CA'}->{'actca'};
   }
   if(not defined($ca)) {
      $main->print_warning("Can't get CA name");
   }

   $action = $main->show_config_crl($ca);

   return if $action eq 'Cancel';

   _write_config($self, $main, $ca);

   return;
}

sub _write_config {
   my $self = shift;
   my $main = shift;
   my $ca   = shift;

   my($file, @sections, $line, $sect, $key, $val, @opts);

   # these sections are not configurable
   @sections = qw(
         ca 
         policy_client 
         policy_server 
         req 
         req_distinguished_name 
         v3_req 
         req_attributes
         );


   $file = $main->{'CA'}->{$ca}->{'cnf'};

   open(OUT, ">$file") || do {
      $main->print_warning("Can't open Configfile");
      return;
   };

   foreach $sect (@sections) {
      print OUT "[ $sect ]\n";
      foreach $line (@{$self->{$sect}}) {
         print OUT "$line\n";
      }
      print OUT "\n";
   }

   # these sections are configurable
   @sections = qw(
         v3_ca 
         crl_ext
         server_ca 
         client_ca 
         client_cert 
         server_cert
         );

   foreach $sect (@sections) {
      print OUT "[ $sect ]\n";
      if($sect eq "v3_ca") {
         @opts = qw( 
               subjectKeyIdentifier
               authorityKeyIdentifier
               basicConstraints
               keyUsage
               nsCertType
               subjectAltName
               issuerAltName
               nsComment
               crlDistributionPoints
               nsCaRevocationUrl
               nsCaPolicyUrl
               nsRevocationUrl
               nsRenewalUrl
               );

         foreach $key (@opts) {
          if(defined($self->{$sect}->{$key}) && 
             $self->{$sect}->{$key}  ne "") {
             print OUT "$key = $self->{$sect}->{$key}\n";
          }
         }
      } elsif($sect eq "server_cert" ||
              $sect eq "client_cert" ) {
         @opts = qw( 
               basicConstraints
               nsCertType
               nsComment
               subjectKeyIdentifier
               authorityKeyIdentifier
               subjectAltName
               issuerAltName
               crlDistributionPoints
               nsCaRevocationUrl
               nsBaseUrl
               nsRevocationUrl
               nsRenewalUrl
               nsCaPolicyUrl
               );

         foreach $key (@opts) {
          if(defined($self->{$sect}->{$key}) && 
             $self->{$sect}->{$key}  ne "") {
             print OUT "$key = $self->{$sect}->{$key}\n";
          }
         }
      } elsif(($sect eq "server_ca") ||
              ($sect eq "client_ca")) {
         @opts = qw( 
               dir
               certs
               crl_dir
               database
               new_certs_dir
               certificate
               serial
               crl
               private_key
               RANDFILE
               x509_extensions
               default_days
               default_crl_days
               default_md
               preserve
               policy
               );

         foreach $key (@opts) {
          if(defined($self->{$sect}->{$key}) && 
             $self->{$sect}->{$key}  ne "") {
             print OUT "$key = $self->{$sect}->{$key}\n";
          }
         }
      } else {
         while(($key, $val) = each(%{$self->{$sect}})) {
            if(defined($val) && $val ne "") {
             print OUT "$key = $val\n";
            }
         }
      }
      print OUT "\n";
   }

   close OUT;

   return;
}
   
1

==> tinyca-0.5.2.tar.gz: TinyCA/lib/TCONFIG.pm <==
# Copyright (c) Stephan Martin <sm@sm-zone.net>
#
# $Id: TCONFIG.pm,v 1.4 2003/08/22 20:36:56 sm Exp $
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.

use strict;

package TCONFIG;

use POSIX;
use Locale::gettext;

sub new {
   my $self  = {};
   my $that  = shift;
   my $class = ref($that) || $that;

   bless($self, $class);
}

sub init_config {
   my ($self, $main, $ca) = @_;

   my($file, @lines, $i, $section, $l, $k, $v);

   if(not defined($ca)) {
     $ca = $main->{'CA'}->{'actca'};
   }
   if(not defined($ca)) {
      $main->print_warning(gettext("Please select a CA first"));
      return;
   }

   $file = $main->{'CA'}->{$ca}->{'cnf'};

   open(IN, "<$file") || do {
      $main->print_warning(gettext("Can't open configuration"));
      return;
   };

   @lines = <IN>;
   close IN;
   chomp(@lines);

   # clean old configuration
   foreach $k (keys(%$self)) {
      delete($self->{$k});
   }

   foreach $l (@lines) {
      next if $l =~ /^#/;
      next if $l =~ /^$/;
      next if $l =~ /^ *$/;

      # find section
      if($l =~ /\[\s*([^\s]+)\s*\]/) {
         $section = $1;
      } elsif ($l =~ /^([^\s\t]+)[\s\t]*=[\s\t]*([^\s\t]+.*)$/) {
         if($section eq "ca" ||
            $section eq "policy_client" ||
            $section eq "policy_server" ||
            $section eq "req" ||
            $section eq "req_distinguished_name" ||
            $section eq "v3_req" ||
            $section eq "req_attributes") {
            if(not defined($self->{$section})) {
               $self->{$section} = [];
            }
            push(@{$self->{$section}}, $l);
         } else {
            $k = $1;
            $v = $2;
            if(not defined($self->{$section})) {
               $self->{$section} = {};
            }
            $self->{$section}->{$k} = $v;
         }
      }
   }
   return;
}

sub config_ca {
   my ($self, $main, $ca) = @_;

   my($action);

   if(not defined($ca)) { 
      $ca = $main->{'CA'}->{'actca'};
   }
   if(not defined($ca)) {
      $main->print_warning(gettext("Can't get CA name"));
   }

   $action = $main->show_config_ca($ca);

   return if $action eq gettext("Cancel");

   _write_config($self, $main, $ca);

   return;
}

sub config_openssl {
   my ($self, $main, $ca) = @_;

   if(not defined($ca)) { 
      $ca = $main->{'CA'}->{'actca'};
   }
   if(not defined($ca)) {
      $main->print_warning(gettext("Can't get CA name"));
   }

   $main->show_configbox($ca);

   return;
}

sub write_config {
   my ($self, $main, $ca) = @_;

   my($file, @sections, $line, $sect, $key, $val, @opts);

   # these sections are not configurable
   @sections = qw(
         ca 
         policy_client 
         policy_server 
         req 
         req_distinguished_name 
         v3_req 
         req_attributes
         );


   $file = $main->{'CA'}->{$ca}->{'cnf'};

   open(OUT, ">$file") || do {
      $main->print_warning(gettext("Can't open configfile"));
      return;
   };

   foreach $sect (@sections) {
      print OUT "[ $sect ]\n";
      foreach $line (@{$self->{$sect}}) {
         print OUT "$line\n";
      }
      print OUT "\n";
   }

   # these sections are configurable
   @sections = qw(
         v3_ca 
         crl_ext
         server_ca 
         client_ca 
         client_cert 
         server_cert
         );

   foreach $sect (@sections) {
      print OUT "[ $sect ]\n";
      if($sect eq "v3_ca") {
         @opts = qw( 
               subjectKeyIdentifier
               authorityKeyIdentifier
               basicConstraints
               keyUsage
               nsCertType
               subjectAltName
               issuerAltName
               nsComment
               crlDistributionPoints
               nsCaRevocationUrl
               nsCaPolicyUrl
               nsRevocationUrl
               nsRenewalUrl
               );

         foreach $key (@opts) {
          if(defined($self->{$sect}->{$key}) && 
             $self->{$sect}->{$key}  ne "") {
             print OUT "$key = $self->{$sect}->{$key}\n";
          }
         }
      } elsif($sect eq "server_cert" ||
              $sect eq "client_cert" ) {
         @opts = qw( 
               basicConstraints
               nsCertType
               nsComment
               subjectKeyIdentifier
               authorityKeyIdentifier
               subjectAltName
               issuerAltName
               crlDistributionPoints
               nsCaRevocationUrl
               nsBaseUrl
               nsRevocationUrl
               nsRenewalUrl
               nsCaPolicyUrl
               );

         foreach $key (@opts) {
          if(defined($self->{$sect}->{$key}) && 
             $self->{$sect}->{$key}  ne "") {
             print OUT "$key = $self->{$sect}->{$key}\n";
          }
         }
      } elsif(($sect eq "server_ca") ||
              ($sect eq "client_ca")) {
         @opts = qw( 
               dir
               certs
               crl_dir
               database
               new_certs_dir
               certificate
               serial
               crl
               private_key
               RANDFILE
               x509_extensions
               default_days
               default_crl_days
               default_md
               preserve
               policy
               );

         foreach $key (@opts) {
          if(defined($self->{$sect}->{$key}) && 
             $self->{$sect}->{$key}  ne "") {
             print OUT "$key = $self->{$sect}->{$key}\n";
          }
         }
      } else {
         while(($key, $val) = each(%{$self->{$sect}})) {
            if(defined($val) && $val ne "") {
             print OUT "$key = $val\n";
            }
         }
      }
      print OUT "\n";
   }

   close OUT;

   return;
}
   
1
